==> entity_usage_light-1.0.0.tar.gz: entity_usage_light/src/Form/SettingsForm.php <==
<?php

namespace Drupal\entity_usage_light\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for entity_usage_light settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_usage_light_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['entity_usage_light.settings'];
  }

  /**
   * Constructs a new setting form object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    parent::__construct($config_factory);

    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_usage_light.settings');

    $entity_types = $this->entityTypeManager->getDefinitions();
    $entity_types = array_filter($entity_types, function (EntityTypeInterface $entity_type) {
      return $entity_type instanceof ContentEntityTypeInterface;
    });

    // Active on.
    $active_on_default_value = $config->get('active_on') ?? (in_array('node', array_keys($entity_types)) ? ['node' => 'node'] : []);

    $form['active_on'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content entity types'),
      '#options' => array_combine(array_keys($entity_types), array_keys($entity_types)),
      '#default_value' => $active_on_default_value,
      '#description' => '<p>' . $this->t('Activate "Entity Usage (light)" tab on specific entity types.') . '</p>' .
        '<p>' . $this->t('Selected entity types will have an "Entity Usage (light)" tab in their local tasks.') . '</p>' .
        '<p>' . $this->t('Currently selected:&nbsp;<strong>@list</strong>', [
          '@list' => implode(', ', array_filter($active_on_default_value)),
        ]) . '</p>',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('entity_usage_light.settings');
    $exclude = ['submit', 'form_build_id', 'form_token', 'form_id', 'op'];
    foreach ($form_state->getValues() as $key => $data) {
      if (!in_array($key, $exclude)) {
        $config->set($key, $data);
      }
    }
    $config->save();

    // Clear enough caches to enable/disable "Usage" tab for selected entity types.
    \Drupal::service('plugin.cache_clearer')->clearCachedDefinitions();
    \Drupal::service('router.builder')->rebuild();
    $this->messenger()->addStatus($this->t('Caches cleared.'));

    parent::submitForm($form, $form_state);
  }
}

==> entity_usage_light-1.0.3.tar.gz: entity_usage_light/src/Form/SettingsForm.php <==
<?php

namespace Drupal\entity_usage_light\Form;

use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for entity_usage_light settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The plugin cache clearer.
   *
   * @var \Drupal\Core\Plugin\CachedDiscoveryClearerInterface
   */
  protected $pluginCacheClearer;

  /**
   * The route builder service.
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routeBuilder;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_usage_light_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['entity_usage_light.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    $instance->pluginCacheClearer = $container->get('plugin.cache_clearer');
    $instance->routeBuilder = $container->get('route.builder');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_usage_light.settings');

    $entity_types = $this->entityTypeManager->getDefinitions();
    $entity_types = array_filter($entity_types, function (EntityTypeInterface $entity_type) {
      return $entity_type instanceof ContentEntityTypeInterface;
    });

    // Active on.
    $active_on_default_value = $config->get('active_on') ?? [];

    $form['active_on'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content entity types'),
      '#options' => array_combine(array_keys($entity_types), array_keys($entity_types)),
      '#default_value' => $active_on_default_value,
      '#description' => '<p>' . $this->t('Activate "Entity Usage (light)" tab on specific entity types.') . '</p>' .
      '<p>' . $this->t('Selected entity types will have an "Entity Usage (light)" tab in their local tasks.') . '</p>' .
      '<p>' . $this->t('Currently selected:&nbsp;<strong>@list</strong>', [
        '@list' => implode(', ', array_filter($active_on_default_value)),
      ]) . '</p>',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('entity_usage_light.settings');
    $exclude = ['submit', 'form_build_id', 'form_token', 'form_id', 'op'];
    foreach ($form_state->getValues() as $key => $data) {
      if (!in_array($key, $exclude)) {
        $config->set($key, $data);
      }
    }
    $config->save();

    // Clear enough caches to enable/disable "Usage" tab for selected entity types.
    $this->pluginCacheClearer->clearCachedDefinitions();
    $this->routeBuilder->rebuild();
    $this->messenger()->addStatus($this->t('Caches cleared.'));

    parent::submitForm($form, $form_state);
  }

}
